using System;
using System.Xml;

namespace com.ibm.gre
{
	/// <summary>
	/// The IRMComponent class is used to encapsulate
	/// typical Records Manager component values that
	/// are stored in the Tag property of a Node in a
	/// ListView or TreeView control.
	/// When a new node is added to a Tree or List View
	/// information about the Records manager Component that
	/// the node represents is stored in an instance of this class.
	/// The instance is then assigned to the Tag property of the Node
	/// and can be retrieved for future use.
	/// For example when a user whishes to view the properties of
	/// a File Plan Component displayed in a Tree or List View
	/// the IRMComponent object that is stored in the Node representing that
	/// component can be accessed to determine the "FlPlnCmpntID".
	/// The Records Manager API can then be used to return information
	/// about the component.
	/// </summary>
	public class IRMComponent
	{
		/// <summary>
		/// Default Constructor
		/// </summary>
		public IRMComponent()
		{
			this.nFlPlnCmpntID = 0;
			this.strFlPlnCmpntNm = "";
			this.strFlPlnCmpntCode = "";
			this.strFlPlnCmpntTtl = "";
			this.nFlPlnCmpntDefID = ROOT;
			this.strFlPlnCmpntDefNm = "Views";
			this.nFlPlnCmpntDefTyp = 0;
			this.nFlPlnViewID = 0;
			this.strFlPlnViewNm = "";
			this.bHasTgt = false;
			this.nSecClsID = 0;
			this.nSecClsLvl = 0; 
		}

		/// <summary>
		/// Constructor used specifically for View Components.
		/// </summary>
		/// <param name="nFlPlnViewID">The unique number identifying the View.</param>
		/// <param name="strFlPlnViewNm">The unique name identiying the View.</param>

		public IRMComponent(int nFlPlnViewID, string strFlPlnViewNm)
		{
			this.nFlPlnCmpntID = 0;
			this.strFlPlnCmpntNm = "";
			this.strFlPlnCmpntCode = "";
			this.strFlPlnCmpntTtl = "";
			this.nFlPlnCmpntDefID = (int)IRMConstants.ComponentDefinitionTypes.FILE_PLAN_VIEW;
			this.strFlPlnCmpntDefNm = "FilePlanView";
			this.nFlPlnCmpntDefTyp = 0;
			this.nFlPlnViewID = nFlPlnViewID;
			this.strFlPlnViewNm = strFlPlnViewNm;
			this.bHasTgt = true;
			this.nSecClsID = 0;
			this.nSecClsLvl = 0; 
		}

		/// <summary>
		/// Constructor using Item element.
		/// </summary>
		/// <param name="item">The XML Item element returned from a call to the Records Manager "getTargetList" method.</param>

		public IRMComponent(XmlNode item)
		{
			this.nFlPlnCmpntID = System.Convert.ToInt64(item.Attributes.GetNamedItem("FlPlnCmpntID").Value);
			this.strFlPlnCmpntNm = item.Attributes.GetNamedItem("FlPlnCmpntNm").Value;
			this.strFlPlnCmpntCode = item.Attributes.GetNamedItem("FlPlnCmpntCode").Value;
			this.strFlPlnCmpntTtl = item.Attributes.GetNamedItem("FlPlnCmpntTtl").Value;
			this.nFlPlnCmpntDefID = System.Convert.ToInt32(item.Attributes.GetNamedItem("FlPlnCmpntDefID").Value);
			this.strFlPlnCmpntDefNm = item.Attributes.GetNamedItem("FlPlnCmpntDefNm").Value;
			this.nFlPlnCmpntDefTyp = System.Convert.ToByte(item.Attributes.GetNamedItem("FlPlnCmpntDefTyp").Value);
			this.nFlPlnViewID = System.Convert.ToInt32(item.Attributes.GetNamedItem("FlPlnViewID").Value);
			this.strFlPlnViewNm = item.Attributes.GetNamedItem("FlPlnViewNm").Value;
			this.bHasTgt = (item.Attributes.GetNamedItem("HasTgt").Value != "0");
			this.nSecClsID = System.Convert.ToInt32(item.Attributes.GetNamedItem("SecClsID").Value);
			this.nSecClsLvl = System.Convert.ToInt32(item.Attributes.GetNamedItem("SecClsLvl").Value); 
		}

		/// <summary>
		/// Constructor containing parameters for all property values.
		/// </summary>
		/// <param name="nFlPlnCmpntID">The unique number identifying the Component.</param>
		/// <param name="strFlPlnCmpntNm">The unique name identifying the Component.</param>
		/// <param name="strFlPlnCmpntTtl">The Component Title.</param>
		/// <param name="nFlPlnCmpntDefID">The Component Definition ID.</param>
		/// <param name="strFlPlnCmpntDefNm">The Component Definition Name.</param>
		/// <param name="nFlPlnViewID">The Primary View ID for the Component.</param>   
		public IRMComponent(long nFlPlnCmpntID, string strFlPlnCmpntNm, string strFlPlnCmpntTtl, int nFlPlnCmpntDefID, string strFlPlnCmpntDefNm, int nFlPlnViewID)
		{
			this.nFlPlnCmpntID = nFlPlnCmpntID;
			this.strFlPlnCmpntNm = strFlPlnCmpntNm;
			this.strFlPlnCmpntCode = "";
			this.strFlPlnCmpntTtl = strFlPlnCmpntTtl;
			this.nFlPlnCmpntDefID = nFlPlnCmpntDefID;
			this.strFlPlnCmpntDefNm = strFlPlnCmpntDefNm;
			this.nFlPlnCmpntDefTyp = 0;
			this.nFlPlnViewID = nFlPlnViewID;
			this.strFlPlnViewNm = "";
			this.bHasTgt = true;
			this.nSecClsID = 0;
			this.nSecClsLvl = 0; 
		}

		public long FlPlnCmpntID
		{
			get
			{
				return this.nFlPlnCmpntID;
			}
		}

		public string FlPlnCmpntNm
		{
			get
			{
				return this.strFlPlnCmpntNm;
			}
			set
			{
				this.strFlPlnCmpntNm = value;
			}
		}

		public string FlPlnCmpntCode
		{
			get
			{
				return this.strFlPlnCmpntCode;
			}
		}

		public string FlPlnCmpntTtl
		{
			get
			{
				return this.strFlPlnCmpntTtl;
			}
		}

		public long FlPlnCmpntDefID
		{
			get
			{
				return this.nFlPlnCmpntDefID;
			}
		}

		public string FlPlnCmpntDefNm
		{
			get
			{
				return this.strFlPlnCmpntDefNm;
			}
		}

		public byte FlPlnCmpntDefTyp
		{
			get
			{
				return this.nFlPlnCmpntDefTyp;
			}
		}

		public int FlPlnViewID
		{
			get
			{
				return this.nFlPlnViewID;
			}
		}

		public string FlPlnViewNm
		{
			get
			{
				return this.strFlPlnViewNm;
			}
		}

		public bool HasTgt
		{
			get
			{
				return this.bHasTgt;
			}
			set
			{
				this.bHasTgt = value;
			}
		}

		public int SecClsID
		{
			get
			{
				return this.nSecClsID;
			}
		}

		public int SecClsLvl
		{
			get
			{
				return this.nSecClsLvl;
			}
		}

		public static int ROOT = -999;

		//private member variables
		private long nFlPlnCmpntID;
		private string strFlPlnCmpntNm;
		private string strFlPlnCmpntCode;
		private string strFlPlnCmpntTtl;
		private int nFlPlnCmpntDefID;
        private string strFlPlnCmpntDefNm;
        private byte nFlPlnCmpntDefTyp;
        private int nFlPlnViewID;
        private string strFlPlnViewNm;
        private bool bHasTgt;
        private int nSecClsID;
        private int nSecClsLvl;

	}
}
